@@ -49,10 +49,11 @@ monitoring.register(CommandLogger())
 class DBHelper():
     """Class to add and get documents from a mongo database using mongoengine
     """
-    def __init__(self, dbname="persistencedb"):
+    def __init__(self, dbname):
         with open("ca-certificate.crt", "w") as text_file:
             text_file.write(os.getenv('DATABASE_CERT'))
         mongoengine.connect(host="mongodb+srv://"+ os.getenv("DATABASE_USERNAME")+":"+ os.getenv("DATABASE_PASSWORD") + "@" +os.getenv("DATABASE_HOST") +"/"+dbname+"?authSource=admin&tls=true&tlsCAFile=ca-certificate.crt")
+    
     def add_item(self, data, collection):
         if collection == "Conversations":
             document = Conversations(obj=data)
@@ -72,7 +73,7 @@ class DBHelper():
             document = ChatData.objects()
         else:
             document = BotData.objects()
-        if document.first() == None:
+        if document.first() is None:
             document = {}
         else:
             document = document.first()['obj']
@@ -94,7 +95,7 @@ class DBPersistence(BasePersistence):
         self.user_data_collection = "UserData"
         self.chat_data_collection = "ChatData"
         self.bot_data_collection = "BotData"
-        self.db = DBHelper()
+        self.db = DBHelper(dbname=dbname)
         self.user_data = None
         self.chat_data = None
         self.bot_data = None
