@@ -4,6 +4,7 @@ import requests as req
 from requests.exceptions import Timeout
 from configparser import ConfigParser 
 import os
+import json
   
 config = ConfigParser() 
 config.read('config.ini')
@@ -15,12 +16,19 @@ class FilterRasa(MessageFilter):
         
     def filter(self, message):
         try:
-            token_response = req.post(config["rasa"]["url"] + "/api/auth", json={"username":os.getenv('RASA_USER'), "password":os.getenv('RASA_PASSWORD')},  timeout = (3, 8))
+            payload = json.dumps({
+            "username": os.getenv('RASA_USER'),
+            "password": os.getenv('RASA_PASSWORD')
+            })
+
+            token_response = req.post(config["rasa"]["url"] + "/api/auth", data=payload)
             print(token_response.json())
+
             RASA_TOKEN = token_response.json()["access_token"]
             response = req.post(config["rasa"]["url"] + "/api/projects/default/logs", params={"q": message.text}, headers={'Authorization': 'Bearer {}'.format(RASA_TOKEN)},  timeout = (3, 8))
             print(response.json())
-        except Timeout:
+        except (Timeout, KeyError) as e:
+            print(e)
             False
         else:
             if not response.ok:
